@@ -244,13 +244,13 @@ class n0Vault(dict):
         if self.is_bit_set(2, 0b1):
             raise Exception(f"Saving of such n0Vault storage is forbidden")
         # ******************************************************************************************
-        def write_buffer(buffer: typing.Union[str, int], name_of_buffer: str):
+        def write_buffer(buffer: typing.Union[str, int, bytes], name_of_buffer: str):
             n0debug_calc(buffer, name_of_buffer)
             if isinstance(buffer, str):
                 buffer = buffer.encode("utf-8")             # str -> bytes
             elif isinstance(buffer, int):
                 buffer = buffer.to_bytes(4, 'little')       # int32 -> bytes
-            else:
+            elif not isinstance(buffer, bytes):
                 raise(Exception(f"Expected type str or int for '{buffer}', but got {type(buffer)}"))
             out_file.write(buffer)
         # ******************************************************************************************
